@@ -1,5 +1,5 @@
 ## =====================================================
-## Translate sequences as character strings into vectors 
+## Translate sequences as character strings into vectors
 ## (one column (variable) for each state/event)
 ## =====================================================
 
@@ -20,14 +20,14 @@ seqdecomp <- function(data, var=NULL, sep="-", miss="NA", vnames=NULL) {
 	
 	sdecomp <- matrix(nrow=nbseq, ncol=lmax)
 	rownames(sdecomp) <- paste("[",seq(1:nbseq),"]",sep="")
-	if (is.null(vnames)) 
+	if (is.null(vnames))
 		colnames(sdecomp) <- paste("[",seq(1:lmax),"]",sep="")
-	else 
+	else
 		colnames(sdecomp) <- vnames
 
 	for (i in 1:nbseq) {
 		seq <- tmp[[i]]
-		seq[seq==miss] <- NA
+		seq[seq %in% miss] <- NA
 		if (sl[i] < lmax) seq <- c(seq,rep(NA,lmax-sl[i]))
 		sdecomp[i,] <- seq
 		}
